;; Generated package description from plz.el  -*- no-byte-compile: t -*-
(define-package "plz" "0.9.0.20240610.142147" "HTTP library" '((emacs "27.1")) :commit "399ad3e1aafa7b86c1ce0cfab8bcf2e09cb0e956" :authors '(("Adam Porter" . "adam@alphapapa.net")) :maintainer '("Adam Porter" . "adam@alphapapa.net") :keywords '("comm" "network" "http") :url "https://github.com/alphapapa/plz.el")
